Skip to contents

This is the ratio of the acceleration due to gravity and the specific heat of the air, according to (3.53) of Reference 2.

Usage

dryLapseRate(g = 9.7986, C_P = 1004)

Arguments

g

acceleration due to gravity, with the default as listed in Reference 2.

C_P

numeric value of the specific heat of air at sea level, with the default being as listed in Reference 2, converted to J/(kg*K).

Value

dryLapseRate returns the lapse rate, in degrees C (or Kelvin) per metre.

References

  1. Wallace, John M., and Peter Victor Hobbs. Atmospheric Science: An Introductory Survey. 2nd ed. International Geophysics Series,

  2. https://pds-atmospheres.nmsu.edu/education_and_outreach/encyclopedia/adiabatic_lapse_rate.htm

Author

Dan Kelley