Skip to contents

This is done by integrating dTdp_moist() from p=100.5e3 Pa (1005 mbar) to 1e3 Pa (100 mbar). Note that the computation is done in Pa and Kelvin, so we need to do conversions at start and end, because this is used by plot.sounding(), which works in those units.

Usage

moistAdiabat(TC)

Arguments

TC

temperature in degrees Celcius.

Value

moistAdiabat' returns a data frame with p(in mbar) and temperatureT` (in degC).