Skip to contents

Based on the plotted data range and figure geometry, this determines a temperature skew that be equivalent to a 45 degree rotation of isotherms. A warning will be issued if the graph is far from square or the axes cover unexpected ranges.

Usage

skew(pressure)

Arguments

pressure

numeric vector holding the pressures in the sounding dataset.

Value

skew returns the value to be added to temperature, as a function of the supplied pressure.

Author

Dan Kelley