Read an HTML file downloaded by downloadSounding(). This
code works by recognizing portions of the file as preformatted blocks, which
is a brittle method that will fail if the HTML format used on the server website
changes. Obviously, it would be better to work with csv or json files, but
we have no way to know how to download such files, since the server provides
no documentation.
Arguments
- file
character value indicating the name of a sounding file. This file must have been downloaded with
downloadSounding().
Examples
library(atm)
file <- system.file("extdata", "Shearwater_2024-07-11.txt.gz", package = "atm")
sounding <- readSounding(file)