Based on the plotted data range and figure geometry, this determines a temperature skew that be equivalent to a 45 degree rotation of isotherms. A warning will be issued if the graph is far from square or the axes cover unexpected ranges.
Based on the plotted data range and figure geometry, this determines a temperature skew that be equivalent to a 45 degree rotation of isotherms. A warning will be issued if the graph is far from square or the axes cover unexpected ranges.